#  pygyver

Contains Data Enginner, Data Scientist and 3rd party integration tools capabilities

## Installation
py-test-utility can be installed via pip

```python 
pip install pygyver
```


## [DS Libraries](../master/utils/README.md)

```
PROJECT_ROOT=  "root of he project"

AWS_ACCESS_KEY_ID=
AWS_SECRET_ACCESS_KEY=
AWS_DEFAULT_REGION=
AWS_S3_BUCKET=
AWS_S3_ROOT=
AWS_S3_PRODUCT_FEED_BUCKET=madecom-product-feed

GOOGLE_APPLICATION_CREDENTIALS=  "path to the json token file."
BIGQUERY_PROJECT= "default name of the project in BigQuery. Default project cannot be changed in the code."

```

BigQuery functions wrap `bigpyquery` functions to provide higher level API removing boilerplate instructions of the lower level API.
